@@ -206,7 +206,14 @@ def cmd_upload_resource( args ):
 		method = 'POST'
 		url = 'resource'
 	
-	r = api_request( method, url, query_string = query, data_file = args.local_file, headers = headers )
+
+	if args.local_file.startswith('http:') or args.local_file.startswith( 'https:' ):
+		data_file = None
+		query['fetch_url'] = args.local_file
+	else:
+		data_file = args.local_file
+		
+	r = api_request( method, url, query_string = query, data_file = data_file, headers = headers )
 	return handle_object_response( args, r )
 	
 	
@@ -313,7 +320,7 @@ def main():
 	o = add_local( 'get-resource', 'get the binary data for the resource', with_path = True )
 	
 	o = add_local( 'upload-resource', 'upload a resource' )
-	o.add_argument( 'local_file', metavar = 'local-file',  help = 'name of local file to upload' )
+	o.add_argument( 'local_file', metavar = 'local-file',  help = 'name of local file to upload, or URL to fetch' )
 	o.add_argument( 'path', help = 'resource name or id, if not specified then a unique ID is chosen', 
 		nargs = '?' )
 	o.add_argument( '--content-type', help = 'specify a content-type, otherwise guess based on filename' )
